import wx
import pyperclip
import urllib.parse

class TeamTalkLinkGenerator(wx.Frame):
    def __init__(self, parent, title):
        super(TeamTalkLinkGenerator, self).__init__(parent, title=title, size=(400, 300))

        self.InitUI()

    def InitUI(self):
        panel = wx.Panel(self)

        sizer = wx.BoxSizer(wx.VERTICAL)

        # Label and Text Control for Hostname
        hostname_label = wx.StaticText(panel, label="Enter a hostname:")
        self.hostname_text = wx.TextCtrl(panel)
        sizer.Add(hostname_label, 0, wx.ALL, 5)
        sizer.Add(self.hostname_text, 0, wx.EXPAND | wx.ALL, 5)

        # TCP Port
        tcp_label = wx.StaticText(panel, label="Enter a TCP port:")
        self.tcp_spin = wx.SpinCtrl(panel, min=0, max=65535)
        sizer.Add(tcp_label, 0, wx.ALL, 5)
        sizer.Add(self.tcp_spin, 0, wx.EXPAND | wx.ALL, 5)

        # UDP Port
        udp_label = wx.StaticText(panel, label="Enter a UDP port:")
        self.udp_spin = wx.SpinCtrl(panel, min=0, max=65535)
        sizer.Add(udp_label, 0, wx.ALL, 5)
        sizer.Add(self.udp_spin, 0, wx.EXPAND | wx.ALL, 5)

        # Encrypted Checkbox
        self.encrypt_checkbox = wx.CheckBox(panel, label="Is this server encrypted?")
        sizer.Add(self.encrypt_checkbox, 0, wx.ALL, 5)

        # Username
        username_label = wx.StaticText(panel, label="Enter a username:")
        self.username_text = wx.TextCtrl(panel)
        sizer.Add(username_label, 0, wx.ALL, 5)
        sizer.Add(self.username_text, 0, wx.EXPAND | wx.ALL, 5)

        # Password
        password_label = wx.StaticText(panel, label="Enter a password:")
        self.password_text = wx.TextCtrl(panel)
        sizer.Add(password_label, 0, wx.ALL, 5)
        sizer.Add(self.password_text, 0, wx.EXPAND | wx.ALL, 5)

        # Channel Name
        channel_label = wx.StaticText(panel, label="Enter a channel name:")
        self.channel_text = wx.TextCtrl(panel)
        sizer.Add(channel_label, 0, wx.ALL, 5)
        sizer.Add(self.channel_text, 0, wx.EXPAND | wx.ALL, 5)

        # Channel Password
        channel_password_label = wx.StaticText(panel, label="Enter the password for the channel:")
        self.channel_password_text = wx.TextCtrl(panel)
        sizer.Add(channel_password_label, 0, wx.ALL, 5)
        sizer.Add(self.channel_password_text, 0, wx.EXPAND | wx.ALL, 5)

        # Generate Button
        generate_button = wx.Button(panel, label="Generate Link")
        generate_button.Bind(wx.EVT_BUTTON, self.OnGenerateLink)
        sizer.Add(generate_button, 0, wx.ALL | wx.CENTER, 5)

        panel.SetSizer(sizer)

    def OnGenerateLink(self, event):
        try:
            hostname = self.hostname_text.GetValue()
            tcp_port = self.tcp_spin.GetValue()
            udp_port = self.udp_spin.GetValue()
            encrypted = 1 if self.encrypt_checkbox.IsChecked() else 0
            username = self.username_text.GetValue()
            password = self.password_text.GetValue()
            channel = self.channel_text.GetValue()
            chanpasswd = self.channel_password_text.GetValue()

            # URL encoding
            link = f"tt://{urllib.parse.quote(hostname)}?tcpport={tcp_port}&udpport={udp_port}&encrypted={encrypted}&username={urllib.parse.quote(username)}&password={urllib.parse.quote(password)}&channel={urllib.parse.quote(channel)}&chanpasswd={urllib.parse.quote(chanpasswd)}"

            # Copy to clipboard
            pyperclip.copy(link)

            wx.MessageBox("Link has been copied to clipboard.", "Success", wx.OK | wx.ICON_INFORMATION)
        except Exception as e:
            wx.MessageBox(f"An error occurred: {str(e)}", "Error", wx.OK | wx.ICON_ERROR)

def main():
    app = wx.App(False)
    frame = TeamTalkLinkGenerator(None, "TeamTalk Link Generator")
    frame.Show()
    app.MainLoop()

if __name__ == '__main__':
    main()